pub struct NetworkCapability(/* private fields */);Expand description
Capabilities of a network.
Implementations
Sourceimpl NetworkCapability
impl NetworkCapability
pub const UNMETERED: NetworkCapability
pub const UNCONGESTED: NetworkCapability
pub const NOT_BANDWIDTH_CONSTRAINED: NetworkCapability
Sourceimpl NetworkCapability
impl NetworkCapability
Sourcepub const fn empty() -> NetworkCapability
pub const fn empty() -> NetworkCapability
Get a flags value with all bits unset.
Sourcepub const fn all() -> NetworkCapability
pub const fn all() -> NetworkCapability
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<NetworkCapability>
pub const fn from_bits(bits: u32) -> Option<NetworkCapability>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> NetworkCapability
pub const fn from_bits_truncate(bits: u32) -> NetworkCapability
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> NetworkCapability
pub const fn from_bits_retain(bits: u32) -> NetworkCapability
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<NetworkCapability>
pub fn from_name(name: &str) -> Option<NetworkCapability>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: NetworkCapability) -> bool
pub const fn intersects(&self, other: NetworkCapability) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: NetworkCapability) -> bool
pub const fn contains(&self, other: NetworkCapability) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: NetworkCapability)
pub fn insert(&mut self, other: NetworkCapability)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: NetworkCapability)
pub fn remove(&mut self, other: NetworkCapability)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: NetworkCapability)
pub fn toggle(&mut self, other: NetworkCapability)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: NetworkCapability, value: bool)
pub fn set(&mut self, other: NetworkCapability, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: NetworkCapability) -> NetworkCapability
pub const fn intersection(self, other: NetworkCapability) -> NetworkCapability
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: NetworkCapability) -> NetworkCapability
pub const fn union(self, other: NetworkCapability) -> NetworkCapability
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: NetworkCapability) -> NetworkCapability
pub const fn difference(self, other: NetworkCapability) -> NetworkCapability
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: NetworkCapability,
) -> NetworkCapability
pub const fn symmetric_difference( self, other: NetworkCapability, ) -> NetworkCapability
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> NetworkCapability
pub const fn complement(self) -> NetworkCapability
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl NetworkCapability
impl NetworkCapability
Sourcepub const fn iter(&self) -> Iter<NetworkCapability> ⓘ
pub const fn iter(&self) -> Iter<NetworkCapability> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<NetworkCapability> ⓘ
pub const fn iter_names(&self) -> IterNames<NetworkCapability> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl NetworkCapability
impl NetworkCapability
pub fn from_bits_allow_unknown(bits: u32) -> NetworkCapability
pub fn has_unknown_bits(&self) -> bool
pub fn get_unknown_bits(&self) -> u32