pub struct ProtoProperties(/* private fields */);Expand description
A bitset to represent whether a condition is true across the IPv4 and IPv6 protocols.
Implementations
Sourceimpl ProtoProperties
impl ProtoProperties
pub const V4: ProtoProperties
pub const V6: ProtoProperties
Sourceimpl ProtoProperties
impl ProtoProperties
Sourcepub const fn empty() -> ProtoProperties
pub const fn empty() -> ProtoProperties
Get a flags value with all bits unset.
Sourcepub const fn all() -> ProtoProperties
pub const fn all() -> ProtoProperties
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u8) -> Option<ProtoProperties>
pub const fn from_bits(bits: u8) -> Option<ProtoProperties>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u8) -> ProtoProperties
pub const fn from_bits_truncate(bits: u8) -> ProtoProperties
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u8) -> ProtoProperties
pub const fn from_bits_retain(bits: u8) -> ProtoProperties
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<ProtoProperties>
pub fn from_name(name: &str) -> Option<ProtoProperties>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: ProtoProperties) -> bool
pub const fn intersects(&self, other: ProtoProperties) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: ProtoProperties) -> bool
pub const fn contains(&self, other: ProtoProperties) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: ProtoProperties)
pub fn insert(&mut self, other: ProtoProperties)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: ProtoProperties)
pub fn remove(&mut self, other: ProtoProperties)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: ProtoProperties)
pub fn toggle(&mut self, other: ProtoProperties)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: ProtoProperties, value: bool)
pub fn set(&mut self, other: ProtoProperties, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: ProtoProperties) -> ProtoProperties
pub const fn intersection(self, other: ProtoProperties) -> ProtoProperties
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: ProtoProperties) -> ProtoProperties
pub const fn union(self, other: ProtoProperties) -> ProtoProperties
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: ProtoProperties) -> ProtoProperties
pub const fn difference(self, other: ProtoProperties) -> ProtoProperties
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: ProtoProperties,
) -> ProtoProperties
pub const fn symmetric_difference( self, other: ProtoProperties, ) -> ProtoProperties
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> ProtoProperties
pub const fn complement(self) -> ProtoProperties
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl ProtoProperties
impl ProtoProperties
Sourcepub const fn iter(&self) -> Iter<ProtoProperties> ⓘ
pub const fn iter(&self) -> Iter<ProtoProperties> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<ProtoProperties> ⓘ
pub const fn iter_names(&self) -> IterNames<ProtoProperties> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.